<?php
/**
 * Footer widget widget class
 *
 * @since 2.8.0
 */

class itodo_widget_footer_links extends WP_Widget {

    function __construct() {
        $widget_ops = array('classname' => 'widget_footer_links', 'description' => esc_html__( "Footer links", 'itodo') );
        parent::__construct('footer-links', esc_html__('Itodo Footer Links', 'itodo'), $widget_ops);
        $this->alt_option_name = 'widget_footer_links';
    }

    function widget($args, $instance) {
        $cache = wp_cache_get('itodo_widget_footer_links', 'widget');

        if ( !is_array($cache) )
            $cache = array();

        if ( ! isset( $args['widget_id'] ) )
            $args['widget_id'] = $this->id;

        if ( isset( $cache[ $args['widget_id'] ] ) ) {
            echo wp_specialchars_decode(esc_attr($cache[ $args['widget_id'] ]));
            return;
        }

        ob_start();
        extract($args);
        $title = ( ! empty( $instance['title'] ) ) ? $instance['title'] : esc_html__( '', 'itodo' );
        $title = apply_filters( 'widget_title', $title, $instance, $this->id_base );
        $link_links_1 = ( ! empty( $instance['link_links_1'] ) ) ? $instance['link_links_1'] : esc_html__( '', 'itodo' );
        $links_1 = ( ! empty( $instance['links_1'] ) ) ? $instance['links_1'] : esc_html__( '', 'itodo' );
        $link_links_2 = ( ! empty( $instance['link_links_2'] ) ) ? $instance['link_links_2'] : esc_html__( '', 'itodo' );
        $links_2 = ( ! empty( $instance['links_2'] ) ) ? $instance['links_2'] : esc_html__( '', 'itodo' );
        $link_links_3 = ( ! empty( $instance['link_links_3'] ) ) ? $instance['link_links_3'] : esc_html__( '', 'itodo' );
        $links_3 = ( ! empty( $instance['links_3'] ) ) ? $instance['links_3'] : esc_html__( '', 'itodo' );
        $link_links_4 = ( ! empty( $instance['link_links_4'] ) ) ? $instance['link_links_4'] : esc_html__( '', 'itodo' );
        $links_4 = ( ! empty( $instance['links_4'] ) ) ? $instance['links_4'] : esc_html__( '', 'itodo' );
        $link_links_5 = ( ! empty( $instance['link_links_5'] ) ) ? $instance['link_links_5'] : esc_html__( '', 'itodo' );
        $links_5 = ( ! empty( $instance['links_5'] ) ) ? $instance['links_5'] : esc_html__( '', 'itodo' );
        ?>
        <?php echo wp_specialchars_decode(esc_attr($before_widget),ENT_QUOTES); ?>
        <h4 class="sx-f-title"><?php echo esc_attr($title); ?></h4>
        <ul>
            <?php if(isset($links_1) && $links_1 != ''){?>
            <li><a href="<?php echo esc_url($link_links_1); ?>"><?php echo esc_attr($links_1); ?></a></li>
            <?php } ?>
            <?php if(isset($links_2) && $links_2 != ''){?>
            <li><a href="<?php echo esc_url($link_links_2); ?>"><?php echo esc_attr($links_2); ?></a></li>
            <?php } ?>
            <?php if(isset($links_3) && $links_3 != ''){?>
            <li><a href="<?php echo esc_url($link_links_3); ?>"><?php echo esc_attr($links_3); ?></a></li>
            <?php } ?>
            <?php if(isset($links_4) && $links_4 != ''){?>
            <li><a href="<?php echo esc_url($link_links_4); ?>"><?php echo esc_attr($links_4); ?></a></li>
            <?php } ?>
            <?php if(isset($links_5) && $links_5 != ''){?>
            <li><a href="<?php echo esc_url($link_links_5); ?>"><?php echo esc_attr($links_5); ?></a></li>
            <?php } ?>
        </ul>
        <?php echo wp_specialchars_decode(esc_attr($after_widget)); ?>
    <?php
        // Reset the global $the_post as this query will have stomped on it
        $cache[$args['widget_id']] = ob_get_flush();
        wp_cache_set('itodo_widget_footer_links', $cache, 'widget');
    }

    function update( $new_instance, $old_instance ) {
        $instance = $old_instance;
        $instance['title'] = strip_tags($new_instance['title']);
        $instance['link_links_1'] = strip_tags($new_instance['link_links_1']);
        $instance['links_1'] = strip_tags($new_instance['links_1']);
        $instance['link_links_2'] = strip_tags($new_instance['link_links_2']);
        $instance['links_2'] = strip_tags($new_instance['links_2']);
        $instance['link_links_3'] = strip_tags($new_instance['link_links_3']);
        $instance['links_3'] = strip_tags($new_instance['links_3']);
        $instance['link_links_4'] = strip_tags($new_instance['link_links_4']);
        $instance['links_4'] = strip_tags($new_instance['links_4']);
        $instance['link_links_5'] = strip_tags($new_instance['link_links_5']);
        $instance['links_5'] = strip_tags($new_instance['links_5']);
        $alloptions = wp_cache_get( 'alloptions', 'options' );
        if ( isset($alloptions['widget_footer_links']) )
            delete_option('widget_footer_links');
        return $instance;
    }

    function form( $instance ) {      
        $title     = isset( $instance['title'] ) ? esc_attr( $instance['title'] ) : '';

        $link_links_1     = isset( $instance['link_links_1'] ) ? esc_url( $instance['link_links_1'] ) : '';
        $links_1     = isset( $instance['links_1'] ) ? esc_attr( $instance['links_1'] ) : '';
        $link_links_2     = isset( $instance['link_links_2'] ) ? esc_url( $instance['link_links_2'] ) : '';
        $links_2     = isset( $instance['links_2'] ) ? esc_attr( $instance['links_2'] ) : '';
        $link_links_3     = isset( $instance['link_links_3'] ) ? esc_url( $instance['link_links_3'] ) : '';
        $links_3     = isset( $instance['links_3'] ) ? esc_attr( $instance['links_3'] ) : '';
        $link_links_4     = isset( $instance['link_links_4'] ) ? esc_url( $instance['link_links_4'] ) : '';
        $links_4     = isset( $instance['links_4'] ) ? esc_attr( $instance['links_4'] ) : '';
        $link_links_5     = isset( $instance['link_links_5'] ) ? esc_url( $instance['link_links_5'] ) : '';
        $links_5     = isset( $instance['links_5'] ) ? esc_attr( $instance['links_5'] ) : '';
?>
    <p><label for="<?php echo esc_attr($this->get_field_id( 'title' )); ?>"><?php esc_html_e( 'Title:', 'itodo' ); ?></label>
    <input class="widefat" id="<?php echo esc_attr($this->get_field_id( 'title' )); ?>" name="<?php echo esc_attr($this->get_field_name( 'title' )); ?>" type="text" value="<?php echo esc_attr($title);?>"/></p>

    <p><label for="<?php echo esc_attr($this->get_field_id( 'link_links_1' )); ?>"><?php esc_html_e( 'Link 1:', 'itodo' ); ?></label>
    <input class="widefat" id="<?php echo esc_attr($this->get_field_id( 'link_links_1' )); ?>" name="<?php echo esc_attr($this->get_field_name( 'link_links_1' )); ?>" type="text" value="<?php echo esc_attr($link_links_1);?>"/></p>

    <p><label for="<?php echo esc_attr($this->get_field_id( 'links_1' )); ?>"><?php esc_html_e( 'Text link 1:', 'itodo' ); ?></label>
    <input class="widefat" id="<?php echo esc_attr($this->get_field_id( 'links_1' )); ?>" name="<?php echo esc_attr($this->get_field_name( 'links_1' )); ?>" type="text" value="<?php echo esc_attr($links_1); ?>"/></p>

    <p><label for="<?php echo esc_attr($this->get_field_id( 'link_links_2' )); ?>"><?php esc_html_e( 'Link 2:', 'itodo' ); ?></label>
    <input class="widefat" id="<?php echo esc_attr($this->get_field_id( 'link_links_2' )); ?>" name="<?php echo esc_attr($this->get_field_name( 'link_links_2' )); ?>" type="text" value="<?php echo esc_attr($link_links_2); ?>"/></p>

    <p><label for="<?php echo esc_attr($this->get_field_id( 'links_2' )); ?>"><?php esc_html_e( 'Text link 2:', 'itodo' ); ?></label>
    <input class="widefat" id="<?php echo esc_attr($this->get_field_id( 'links_2' )); ?>" name="<?php echo esc_attr($this->get_field_name( 'links_2' )); ?>" type="text" value="<?php echo esc_attr($links_2); ?>" /></p>

    <p><label for="<?php echo esc_attr($this->get_field_id( 'link_links_3' )); ?>"><?php esc_html_e( 'Link 3:', 'itodo' ); ?></label>
    <input class="widefat" id="<?php echo esc_attr($this->get_field_id( 'link_links_3' )); ?>" name="<?php echo esc_attr($this->get_field_name( 'link_links_3' )); ?>" type="text" value="<?php echo esc_attr($link_links_3); ?>" /></p>

    <p><label for="<?php echo esc_attr($this->get_field_id( 'links_3' )); ?>"><?php esc_html_e( 'Text link 3:', 'itodo' ); ?></label>
    <input class="widefat" id="<?php echo esc_attr($this->get_field_id( 'links_3' )); ?>" name="<?php echo esc_attr($this->get_field_name( 'links_3' )); ?>" type="text" value="<?php echo esc_attr($links_3); ?>" /></p>

    <p><label for="<?php echo esc_attr($this->get_field_id( 'link_links_4' )); ?>"><?php esc_html_e( 'Link 4:', 'itodo' ); ?></label>
    <input class="widefat" id="<?php echo esc_attr($this->get_field_id( 'link_links_4' )); ?>" name="<?php echo esc_attr($this->get_field_name( 'link_links_4' )); ?>" type="text" value="<?php echo esc_attr($link_links_4);?>" /></p>
    <p><label for="<?php echo esc_attr($this->get_field_id( 'links_4' )); ?>"><?php esc_html_e( 'Text link 4:', 'itodo' ); ?></label>
    <input class="widefat" id="<?php echo esc_attr($this->get_field_id( 'links_4' )); ?>" name="<?php echo esc_attr($this->get_field_name( 'links_4' )); ?>" type="text" value="<?php echo esc_attr($links_4); ?>" /></p>

    <p><label for="<?php echo esc_attr($this->get_field_id( 'link_links_5' )); ?>"><?php esc_html_e( 'Link 5:', 'itodo' ); ?></label>
    <input class="widefat" id="<?php echo esc_attr($this->get_field_id( 'link_links_5' )); ?>" name="<?php echo esc_attr($this->get_field_name( 'link_links_5' )); ?>" type="text" value="<?php echo esc_attr($link_links_5);?>" /></p>
    <p><label for="<?php echo esc_attr($this->get_field_id( 'links_5' )); ?>"><?php esc_html_e( 'Text link 5:', 'itodo' ); ?></label>
    <input class="widefat" id="<?php echo esc_attr($this->get_field_id( 'links_5' )); ?>" name="<?php echo esc_attr($this->get_field_name( 'links_5' )); ?>" type="text" value="<?php echo esc_attr($links_5); ?>" /></p>
<?php
    }
}
function itodo_register_custom_widget_footer_links() {
    register_widget( 'itodo_widget_footer_links' );
}
add_action( 'widgets_init', 'itodo_register_custom_widget_footer_links' );

class itodo_widget_footer_info extends WP_Widget {

    function __construct() {
        $widget_ops = array('classname' => 'widget_footer_info', 'description' => esc_html__( "Footer info", 'itodo') );
        parent::__construct('footer-info', esc_html__('Itodo Footer Info', 'itodo'), $widget_ops);
        $this->alt_option_name = 'widget_footer_info';
    }

    function widget($args, $instance) {
        $cache = wp_cache_get('itodo_widget_footer_info', 'widget');

        if ( !is_array($cache) )
            $cache = array();

        if ( ! isset( $args['widget_id'] ) )
            $args['widget_id'] = $this->id;

        if ( isset( $cache[ $args['widget_id'] ] ) ) {
            echo wp_specialchars_decode(esc_attr($cache[ $args['widget_id'] ]));
            return;
        }

        ob_start();
        extract($args);
        $info_title = ( ! empty( $instance['info_title'] ) ) ? $instance['info_title'] : esc_html__( '', 'itodo' );
        $info_title = apply_filters( 'widget_title', $info_title, $instance, $this->id_base );
        $info_icon_1 = ( ! empty( $instance['info_icon_1'] ) ) ? $instance['info_icon_1'] : esc_html__( '', 'itodo' );
        $phone_1 = ( ! empty( $instance['phone_1'] ) ) ? $instance['phone_1'] : esc_html__( '', 'itodo' );
        $phone_2 = ( ! empty( $instance['phone_2'] ) ) ? $instance['phone_2'] : esc_html__( '', 'itodo' );
        $info_icon_2 = ( ! empty( $instance['info_icon_2'] ) ) ? $instance['info_icon_2'] : esc_html__( '', 'itodo' );
        $info_2 = ( ! empty( $instance['info_2'] ) ) ? $instance['info_2'] : esc_html__( '', 'itodo' );
        $info_icon_3 = ( ! empty( $instance['info_icon_3'] ) ) ? $instance['info_icon_3'] : esc_html__( '', 'itodo' );
        $info_3 = ( ! empty( $instance['info_3'] ) ) ? $instance['info_3'] : esc_html__( '', 'itodo' );
        $info_icon_4 = ( ! empty( $instance['info_icon_4'] ) ) ? $instance['info_icon_4'] : esc_html__( '', 'itodo' );
        $info_4 = ( ! empty( $instance['info_4'] ) ) ? $instance['info_4'] : esc_html__( '', 'itodo' );
        $info_icon_5 = ( ! empty( $instance['info_icon_5'] ) ) ? $instance['info_icon_5'] : esc_html__( '', 'itodo' );
        $info_5 = ( ! empty( $instance['info_5'] ) ) ? $instance['info_5'] : esc_html__( '', 'itodo' );
        ?>
        <?php echo wp_specialchars_decode(esc_attr($before_widget),ENT_QUOTES); ?>
        <h4 class="sx-f-title"><?php echo esc_attr($info_title); ?></h4>
        <ul>
            <?php if(isset($phone_1) && $phone_1 != ''){?>
            <li>
                <div class="widget-info-icon">
                    <i class="<?php echo esc_attr($info_icon_1); ?>"></i>
                </div>
                <div class="widget-info-detail">
                    <a href="tel:<?php echo esc_attr($phone_1); ?>"><?php echo esc_attr($phone_1); ?></a>
                    <a href="tel:<?php echo esc_attr($phone_2); ?>"><?php echo esc_attr($phone_1); ?></a>
                </div>
            </li>
            <?php } ?>
            <?php if(isset($info_2) && $info_2 != ''){?>
            <li>
                <div class="widget-info-icon">
                    <i class="<?php echo esc_attr($info_icon_2); ?>"></i>
                </div>
                <div class="widget-info-detail">
                    <p><?php echo esc_attr($info_2); ?></p>
                </div>
            </li> 
            <?php } ?>
            <?php if(isset($info_3) && $info_3 != ''){?>
            <li>
                <div class="widget-info-icon">
                    <i class="<?php echo esc_attr($info_icon_3); ?>"></i>
                </div>
                <div class="widget-info-detail">
                    <p><?php echo esc_attr($info_3); ?></p>
                </div>
            </li>
            <?php } ?>
        </ul>
        <?php echo wp_specialchars_decode(esc_attr($after_widget)); ?>
    <?php
        // Reset the global $the_post as this query will have stomped on it
        $cache[$args['widget_id']] = ob_get_flush();
        wp_cache_set('itodo_widget_footer_info', $cache, 'widget');
    }

    function update( $new_instance, $old_instance ) {
        $instance = $old_instance;
        $instance['info_title'] = strip_tags($new_instance['info_title']);
        $instance['info_icon_1'] = strip_tags($new_instance['info_icon_1']);
        $instance['phone_1'] = strip_tags($new_instance['phone_1']);
        $instance['phone_2'] = strip_tags($new_instance['phone_2']);
        $instance['info_icon_2'] = strip_tags($new_instance['info_icon_2']);
        $instance['info_2'] = strip_tags($new_instance['info_2']);
        $instance['info_icon_3'] = strip_tags($new_instance['info_icon_3']);
        $instance['info_3'] = strip_tags($new_instance['info_3']);
        
        $alloptions = wp_cache_get( 'alloptions', 'options' );
        if ( isset($alloptions['widget_footer_info']) )
            delete_option('widget_footer_info');
        return $instance;
    }

    function form( $instance ) {      
        $info_title     = isset( $instance['info_title'] ) ? esc_attr( $instance['info_title'] ) : '';

        $info_icon_1     = isset( $instance['info_icon_1'] ) ? esc_attr( $instance['info_icon_1'] ) : '';
        $phone_1     = isset( $instance['phone_1'] ) ? esc_attr( $instance['phone_1'] ) : '';
        $phone_2     = isset( $instance['phone_2'] ) ? esc_attr( $instance['phone_2'] ) : '';
        $info_icon_2     = isset( $instance['info_icon_2'] ) ? esc_attr( $instance['info_icon_2'] ) : '';
        $info_2     = isset( $instance['info_2'] ) ? esc_attr( $instance['info_2'] ) : '';
        $info_icon_3     = isset( $instance['info_icon_3'] ) ? esc_attr( $instance['info_icon_3'] ) : '';
        $info_3     = isset( $instance['info_3'] ) ? esc_attr( $instance['info_3'] ) : '';
?>
    <p><label for="<?php echo esc_attr($this->get_field_id( 'info_title' )); ?>"><?php esc_html_e( 'Title:', 'itodo' ); ?></label>
    <input class="widefat" id="<?php echo esc_attr($this->get_field_id( 'info_title' )); ?>" name="<?php echo esc_attr($this->get_field_name( 'info_title' )); ?>" type="text" value="<?php echo esc_attr($info_title);?>"/></p>

    <p><label for="<?php echo esc_attr($this->get_field_id( 'info_icon_1' )); ?>"><?php esc_html_e( 'Icon 1:', 'itodo' ); ?></label>
    <input class="widefat" id="<?php echo esc_attr($this->get_field_id( 'info_icon_1' )); ?>" name="<?php echo esc_attr($this->get_field_name( 'info_icon_1' )); ?>" type="text" value="<?php echo esc_attr($info_icon_1);?>"/></p>

    <p><label for="<?php echo esc_attr($this->get_field_id( 'phone_1' )); ?>"><?php esc_html_e( 'Phone 1:', 'itodo' ); ?></label>
    <input class="widefat" id="<?php echo esc_attr($this->get_field_id( 'phone_1' )); ?>" name="<?php echo esc_attr($this->get_field_name( 'phone_1' )); ?>" type="text" value="<?php echo esc_attr($phone_1); ?>"/></p>
    <p><label for="<?php echo esc_attr($this->get_field_id( 'phone_2' )); ?>"><?php esc_html_e( 'Phone 2:', 'itodo' ); ?></label>
    <input class="widefat" id="<?php echo esc_attr($this->get_field_id( 'phone_2' )); ?>" name="<?php echo esc_attr($this->get_field_name( 'phone_2' )); ?>" type="text" value="<?php echo esc_attr($phone_2); ?>"/></p>

    <p><label for="<?php echo esc_attr($this->get_field_id( 'info_icon_2' )); ?>"><?php esc_html_e( 'Icon 2:', 'itodo' ); ?></label>
    <input class="widefat" id="<?php echo esc_attr($this->get_field_id( 'info_icon_2' )); ?>" name="<?php echo esc_attr($this->get_field_name( 'info_icon_2' )); ?>" type="text" value="<?php echo esc_attr($info_icon_2); ?>"/></p>

    <p><label for="<?php echo esc_attr($this->get_field_id( 'info_2' )); ?>"><?php esc_html_e( 'Info 2:', 'itodo' ); ?></label>
    <input class="widefat" id="<?php echo esc_attr($this->get_field_id( 'info_2' )); ?>" name="<?php echo esc_attr($this->get_field_name( 'info_2' )); ?>" type="text" value="<?php echo esc_attr($info_2); ?>" /></p>

    <p><label for="<?php echo esc_attr($this->get_field_id( 'info_icon_3' )); ?>"><?php esc_html_e( 'Icon 3:', 'itodo' ); ?></label>
    <input class="widefat" id="<?php echo esc_attr($this->get_field_id( 'info_icon_3' )); ?>" name="<?php echo esc_attr($this->get_field_name( 'info_icon_3' )); ?>" type="text" value="<?php echo esc_attr($info_icon_3); ?>" /></p>

    <p><label for="<?php echo esc_attr($this->get_field_id( 'info_3' )); ?>"><?php esc_html_e( 'Info 3:', 'itodo' ); ?></label>
    <input class="widefat" id="<?php echo esc_attr($this->get_field_id( 'info_3' )); ?>" name="<?php echo esc_attr($this->get_field_name( 'info_3' )); ?>" type="text" value="<?php echo esc_attr($info_3); ?>" /></p>
<?php
    }
}
function itodo_register_custom_widget_footer_info() {
    register_widget( 'itodo_widget_footer_info' );
}
add_action( 'widgets_init', 'itodo_register_custom_widget_footer_info' );

class itodo_widget_footer_about extends WP_Widget {

    function __construct() {
        $widget_ops = array('classname' => 'widget_footer_about', 'description' => esc_html__( "Footer about", 'itodo') );
        parent::__construct('footer-about', esc_html__('Itodo Footer About', 'itodo'), $widget_ops);
        $this->alt_option_name = 'widget_footer_about';
    }

    function widget($args, $instance) {
        $cache = wp_cache_get('itodo_widget_footer_about', 'widget');

        if ( !is_array($cache) )
            $cache = array();

        if ( ! isset( $args['widget_id'] ) )
            $args['widget_id'] = $this->id;

        if ( isset( $cache[ $args['widget_id'] ] ) ) {
            echo wp_specialchars_decode(esc_attr($cache[ $args['widget_id'] ]));
            return;
        }

        ob_start();
        extract($args);
        $about_description = ( ! empty( $instance['about_description'] ) ) ? $instance['about_description'] : esc_html__( '', 'itodo' );
        $phone = ( ! empty( $instance['phone'] ) ) ? $instance['phone'] : esc_html__( '', 'itodo' );
        $about_icon = ( ! empty( $instance['about_icon'] ) ) ? $instance['about_icon'] : esc_html__( '', 'itodo' );
        $about_text = ( ! empty( $instance['about_text'] ) ) ? $instance['about_text'] : esc_html__( '', 'itodo' );
        ?>
        <?php echo wp_specialchars_decode(esc_attr($before_widget),ENT_QUOTES); ?>
        <?php if(isset($about_description) && $about_description != ''){?>
        <p><?php echo esc_attr($about_description); ?></p>
        <?php } ?>
        <?php if(isset($phone) && $phone != ''){?>
        <div class="widget_about-call-section">
            <div class="sx-f-call-icon"><i class="<?php echo esc_attr($about_icon); ?>"></i></div>
            <div class="sx-f-call-section">
                <span><?php echo esc_attr($about_text); ?></span>
                <a href="tel:<?php echo esc_attr($phone); ?>"><?php echo esc_attr($phone); ?></a>
            </div>
        </div>
        <?php } ?>
        <?php echo wp_specialchars_decode(esc_attr($after_widget)); ?>
    <?php
        // Reset the global $the_post as this query will have stomped on it
        $cache[$args['widget_id']] = ob_get_flush();
        wp_cache_set('itodo_widget_footer_about', $cache, 'widget');
    }

    function update( $new_instance, $old_instance ) {
        $instance = $old_instance;
        $instance['about_description'] = strip_tags($new_instance['about_description']);
        $instance['phone'] = strip_tags($new_instance['phone']);
        $instance['about_icon'] = strip_tags($new_instance['about_icon']);
        $instance['about_text'] = strip_tags($new_instance['about_text']);
        
        $alloptions = wp_cache_get( 'alloptions', 'options' );
        if ( isset($alloptions['widget_footer_about']) )
            delete_option('widget_footer_about');
        return $instance;
    }

    function form( $instance ) {      
        $about_description     = isset( $instance['about_description'] ) ? esc_attr( $instance['about_description'] ) : '';
        $phone     = isset( $instance['phone'] ) ? esc_attr( $instance['phone'] ) : '';

        $about_icon     = isset( $instance['about_icon'] ) ? esc_attr( $instance['about_icon'] ) : '';
        $about_text     = isset( $instance['about_text'] ) ? esc_attr( $instance['about_text'] ) : '';
?>
    <p><label for="<?php echo esc_attr($this->get_field_id( 'about_description' )); ?>"><?php esc_html_e( 'Description', 'itodo' ); ?></label>
    <textarea class="widefat" id="<?php echo esc_attr($this->get_field_id( 'about_description' )); ?>" name="<?php echo esc_attr($this->get_field_name( 'about_description' )); ?>" type="textarea"><?php echo esc_attr($about_description);?></textarea></p>

    <p><label for="<?php echo esc_attr($this->get_field_id( 'phone' )); ?>"><?php esc_html_e( 'Phone:', 'itodo' ); ?></label>
    <input class="widefat" id="<?php echo esc_attr($this->get_field_id( 'phone' )); ?>" name="<?php echo esc_attr($this->get_field_name( 'phone' )); ?>" type="text" value="<?php echo esc_attr($phone); ?>"/></p>

    <p><label for="<?php echo esc_attr($this->get_field_id( 'about_icon' )); ?>"><?php esc_html_e( 'Icon:', 'itodo' ); ?></label>
    <input class="widefat" id="<?php echo esc_attr($this->get_field_id( 'about_icon' )); ?>" name="<?php echo esc_attr($this->get_field_name( 'about_icon' )); ?>" type="text" value="<?php echo esc_attr($about_icon); ?>"/></p>

    <p><label for="<?php echo esc_attr($this->get_field_id( 'about_text' )); ?>"><?php esc_html_e( 'Text:', 'itodo' ); ?></label>
    <input class="widefat" id="<?php echo esc_attr($this->get_field_id( 'about_text' )); ?>" name="<?php echo esc_attr($this->get_field_name( 'about_text' )); ?>" type="text" value="<?php echo esc_attr($about_text); ?>" /></p>

<?php
    }
}
function itodo_register_custom_widget_footer_about() {
    register_widget( 'itodo_widget_footer_about' );
}
add_action( 'widgets_init', 'itodo_register_custom_widget_footer_about' );